# Generated by Django 4.2.9 on 2024-01-27 07:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sequence', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sequence',
            name='name',
            field=models.CharField(max_length=255, verbose_name='Name'),
        ),
    ]
